////////////////////////////////////////////////////////////////////// 
// lamp/JointLikelihood.h 
// (c) 2000-2006 Goncalo Abecasis
// 
// This file is distributed as part of the LAMP source code package   
// and may not be redistributed in any form, without prior written    
// permission from the author. Permission is granted for you to       
// modify this file for your own personal use, but modified versions  
// must retain this copyright notice and must not be distributed.     
// 
// Permission is granted for you to use this file to compile LAMP.    
// 
// All computer programs have bugs. Use this file at your own risk.   
// 
// Wednesday March 29, 2006
// 
 
#ifndef __JOINTLIKELIHOOD_H__
#define __JOINTLIKELIHOOD_H__

#include "Houdini.h"

class JointLikelihood : public FuzzyInheritanceTree
   {
   public :
      Vector   frequencies;
      Vector   penetrance;

      JointLikelihood();
      virtual ~JointLikelihood();

      void    SelectMarker(int marker);
      void    SelectAffection(int affection);

      virtual int  CountAlleles(Mantra & m);
      virtual bool ShortScoreVectors(Mantra & m);
      virtual void AllocateMemory(Mantra & m);
      virtual void FillPenetranceMatrix(Mantra & m);
      virtual bool isPhenotyped(Mantra & m, int i);

      virtual double GetAlleleFrequency(int founder, int allele);
      virtual void   UpdateAlleles(int founder, int carrier);
      virtual void   UndoAlleles(int founder, int carrier);

      virtual double JointProbability(Mantra & m);

      virtual void SetupAlleleList(Mantra & m);
      virtual void CleanUpAlleleList(Mantra & m);

      virtual bool IdenticalPenetrances(int founder1, int founder2);

   protected:
      int        affection;
      int        marker;

      IntArray * compatibleAlleles;
      int        allocation;
   };

class QtlLikelihood : public JointLikelihood
   {
   public:
      Vector     means;
      double     variance;

      QtlLikelihood();
      virtual ~QtlLikelihood();

      void       SelectTrait(int trait);

      virtual void FillPenetranceMatrix(Mantra & m);
      virtual bool isPhenotyped(Mantra & m, int i);

   protected:
      int trait;

   };

#endif

 
